@@ -1621,6 +1621,55 @@ $default_ttl = $current_config['default_ttl'] ?? 3600;
 <?php endif; ?>
 
 <script>
+// Bootstrap 5 toast notification function
+function showToast(message, type = 'success') {
+    // Create toast container if it doesn't exist
+    let toastContainer = document.getElementById('toast-container');
+    if (!toastContainer) {
+        toastContainer = document.createElement('div');
+        toastContainer.id = 'toast-container';
+        toastContainer.className = 'toast-container position-fixed bottom-0 end-0 p-3';
+        toastContainer.style.zIndex = '1055';
+        document.body.appendChild(toastContainer);
+    }
+    
+    // Create toast HTML
+    const toastId = 'toast-' + Date.now();
+    const iconClass = type === 'success' ? 'fa-check-circle text-success' : 
+                     type === 'danger' ? 'fa-exclamation-triangle text-danger' : 
+                     'fa-info-circle text-info';
+    
+    const toastHTML = `
+        <div id="${toastId}" class="toast" role="alert" aria-live="assertive" aria-atomic="true">
+            <div class="toast-header">
+                <i class="fa ${iconClass} me-2"></i>
+                <strong class="me-auto">Notification</strong>
+                <button type="button" class="btn-close" data-bs-dismiss="toast" aria-label="Close"></button>
+            </div>
+            <div class="toast-body">
+                ${message}
+            </div>
+        </div>
+    `;
+    
+    // Add toast to container
+    toastContainer.insertAdjacentHTML('beforeend', toastHTML);
+    
+    // Initialize and show toast
+    const toastElement = document.getElementById(toastId);
+    const toast = new bootstrap.Toast(toastElement, {
+        autohide: true,
+        delay: 3000
+    });
+    
+    // Remove toast element after it's hidden
+    toastElement.addEventListener('hidden.bs.toast', function() {
+        toastElement.remove();
+    });
+    
+    toast.show();
+}
+
 // Copy to clipboard function with fallback
 function copyToClipboard(text) {
     if (typeof text !== 'string') {
@@ -1632,7 +1681,7 @@ function copyToClipboard(text) {
     // Check if modern clipboard API is available and we're in secure context
     if (navigator.clipboard && window.isSecureContext) {
         navigator.clipboard.writeText(text).then(function() {
-            showAlert('Copied to clipboard!', 'success');
+            showToast('Copied to clipboard!', 'success');
         }).catch(function(err) {
             console.error('Clipboard API failed: ', err);
             fallbackCopyToClipboard(text);
@@ -1657,13 +1706,13 @@ function fallbackCopyToClipboard(text) {
     try {
         const successful = document.execCommand('copy');
         if (successful) {
-            showAlert('Copied to clipboard!', 'success');
+            showToast('Copied to clipboard!', 'success');
         } else {
-            showAlert('Failed to copy to clipboard', 'danger');
+            showToast('Failed to copy to clipboard', 'danger');
         }
     } catch (err) {
         console.error('Fallback copy failed: ', err);
-        showAlert('Copy to clipboard not supported', 'warning');
+        showToast('Copy to clipboard not supported in this browser', 'danger');
     } finally {
         document.body.removeChild(textArea);
     }
